package sun.awt;

import java.nio.charset.CoderResult;
import java.nio.ByteBuffer;
import java.nio.CharBuffer;
import java.nio.charset.CharsetDecoder;
import java.nio.charset.CharsetEncoder;
import java.nio.charset.Charset;

public class Symbol extends Charset
{
    public Symbol() {
        super("Symbol", (String[])null);
    }
    
    @Override
    public CharsetEncoder newEncoder() {
        return new Symbol.Encoder(this);
    }
    
    @Override
    public CharsetDecoder newDecoder() {
        throw new Error("Decoder is not implemented for Symbol Charset");
    }
    
    @Override
    public boolean contains(Charset charset) {
        return charset instanceof Symbol;
    }
    
    private static class Encoder extends CharsetEncoder
    {
        private static byte[] table_math;
        private static byte[] table_greek;
        
        public Encoder(Charset cs) {
            super(cs, 1.0f, 1.0f);
        }
        
        @Override
        public boolean canEncode(char c) {
            if (c >= '∀' && c <= '⋯') {
                if (Symbol.Encoder.table_math[c - 8704] != 0) {
                    return true;
                }
            }
            else if (c >= 'Α' && c <= 'ϖ' && Symbol.Encoder.table_greek[c - 913] != 0) {
                return true;
            }
            return false;
        }
        
        @Override
        protected CoderResult encodeLoop(CharBuffer charBuffer, ByteBuffer byteBuffer) {
            char[] array = charBuffer.array();
            int n = charBuffer.arrayOffset() + charBuffer.position();
            int n2 = charBuffer.arrayOffset() + charBuffer.limit();
            assert n <= n2;
            int i = (n <= n2) ? n : n2;
            byte[] array2 = byteBuffer.array();
            int n3 = byteBuffer.arrayOffset() + byteBuffer.position();
            int n4 = byteBuffer.arrayOffset() + byteBuffer.limit();
            assert n3 <= n4;
            int n5 = (n3 <= n4) ? n3 : n4;
            try {
                while (i < n2) {
                    int n6 = array[i];
                    if (n4 - n5 < 1) {
                        return CoderResult.OVERFLOW;
                    }
                    if (!this.canEncode((char)n6)) {
                        return CoderResult.unmappableForLength(1);
                    }
                    ++i;
                    if (n6 >= '∀' && n6 <= '⋯') {
                        array2[n5++] = Symbol.Encoder.table_math[n6 - 8704];
                    }
                    else if (n6 >= 'Α' && n6 <= 'ϖ') {
                        array2[n5++] = Symbol.Encoder.table_greek[n6 - 913];
                    }
                    else {
                        continue;
                    }
                }
                return CoderResult.UNDERFLOW;
            }
            finally {
                charBuffer.position(i - charBuffer.arrayOffset());
                byteBuffer.position(n5 - byteBuffer.arrayOffset());
            }
        }
        
        @Override
        public boolean isLegalReplacement(byte[] array) {
            return true;
        }
        
        static {
            Symbol.Encoder.table_math = new byte[] { 34, 0, 100, 36, 0, -58, 68, -47, -50, -49, 0, 0, 0, 39, 0, 80, 0, -27, 45, 0, 0, -92, 0, 42, -80, -73, -42, 0, 0, -75, -91, 0, 0, 0, 0, -67, 0, 0, 0, -39, -38, -57, -56, -14, 0, 0, 0, 0, 0, 0, 0, 0, 92, 0, 0, 0, 0, 0, 0, 0, 126, 0, 0, 0, 0, 0, 0, 0, 0, 64, 0, 0, -69, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -71, -70, 0, 0, -93, -77, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -52, -55, -53, 0, -51, -54, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -59, 0, -60, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 94, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -32, -41, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -68 };
            Symbol.Encoder.table_greek = new byte[] { 65, 66, 71, 68, 69, 90, 72, 81, 73, 75, 76, 77, 78, 88, 79, 80, 82, 0, 83, 84, 85, 70, 67, 89, 87, 0, 0, 0, 0, 0, 0, 0, 97, 98, 103, 100, 101, 122, 104, 113, 105, 107, 108, 109, 110, 120, 111, 112, 114, 86, 115, 116, 117, 102, 99, 121, 119, 0, 0, 0, 0, 0, 0, 0, 74, -95, 0, 0, 106, 118 };
        }
    }
}
